//+------------------------------------------------------------------+
//|                                                BlessingBands.mq4 |
//+------------------------------------------------------------------+
#property copyright ""
#property link      ""

#property indicator_chart_window
#property indicator_buffers 3
#property indicator_color1 LightSeaGreen
#property indicator_color2 LightSeaGreen
#property indicator_color3 LightSeaGreen
//---- indicator parameters
extern string   LabelBBS       = "Bollinger Bands Entry Settings:";
extern int      BollPeriod     =10;  // Period for Bollinger
extern double   BollDistance   =10;  // Up/Down spread
extern double   BollDeviation  =2.0; // Standard deviation multiplier for channel 
extern color    displayColor   = DeepSkyBlue; // default color of display characters
//---- buffers
double MovingBuffer[];
double UpperBuffer[];
double LowerBuffer[];

double Poin;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   //Checking for unconvetional Point digits number
   if (Point == 0.00001) Poin = 0.0001; //5 digits
   else if (Point == 0.001) Poin = 0.01; //3 digits
   else Poin = Point; //Normal
//---- indicators
   SetIndexStyle(0,DRAW_NONE);
   SetIndexBuffer(0,MovingBuffer);
   SetIndexLabel(0,NULL);
   SetIndexStyle(1,DRAW_LINE,STYLE_DOT,1,displayColor);
   SetIndexBuffer(1,UpperBuffer);
   SetIndexStyle(2,DRAW_LINE,STYLE_DOT,1,displayColor);
   SetIndexBuffer(2,LowerBuffer);
   
   //---- indicator short name
   IndicatorShortName("B3BB("+BollPeriod+")");
   SetIndexLabel(1,"B3BB("+BollPeriod+")Upper");
   SetIndexLabel(2,"B3BB("+BollPeriod+")Lower");
//----
   SetIndexDrawBegin(0,BollPeriod);
   SetIndexDrawBegin(1,BollPeriod);
   SetIndexDrawBegin(2,BollPeriod);
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Bollinger Bands                                                  |
//+------------------------------------------------------------------+
int start()
  {
   int    i,k,counted_bars=IndicatorCounted();
   double stdv,deviation;
   double sum,oldval,newres;
//----
   if(Bars<=BollPeriod) return(0);
//---- initial zero
   if(counted_bars<1)
      for(i=1;i<=BollPeriod;i++)
        {
         MovingBuffer[Bars-i]=EMPTY_VALUE;
         UpperBuffer[Bars-i]=EMPTY_VALUE;
         LowerBuffer[Bars-i]=EMPTY_VALUE;
        }
//----
   int limit=Bars-counted_bars;
   if(counted_bars>0) limit++;
   for(i=0; i<limit; i++)
      MovingBuffer[i]=iMA(NULL,0,BollPeriod,0,MODE_SMA,PRICE_OPEN,i);
//----
   i=Bars-BollPeriod+1;
   if(counted_bars>BollPeriod-1) i=Bars-counted_bars-1;
   while(i>=0)
     {
      sum=0.0;
      k=i+BollPeriod-1;
      oldval=MovingBuffer[i];
      while(k>=i)
        {
         newres=Open[k]-oldval;
         sum+=newres*newres;
         k--;
        }
      //deviation=BandsDeviations*MathSqrt(sum/BandsPeriod);
      stdv=iStdDev(Symbol(),0,BollPeriod,0,MODE_SMA,PRICE_OPEN,i);
      deviation=stdv*BollDeviation;
      UpperBuffer[i]=oldval+deviation+NormalizeDouble(BollDistance*Poin,Digits);
      LowerBuffer[i]=oldval-deviation-NormalizeDouble(BollDistance*Poin,Digits);
      i--;
     }
//----
   return(0);
  }
//+------------------------------------------------------------------+